--
-- Purpose: install lib2. lib2 is an extended library for Euphoria 3.1.1,
--          created by Shian Lee.
--
-- Version: install.ex 1.02 for Euphoria 3.1.1, January/20/2018, Shian Lee.
--
-- Note:    * If you don't know what is Euphoria then download Euphoria 3.1.1
--            from http://www.RapidEuphoria.com, read the REFMAN.DOC, and run
--            the tutorials in euphoria/tutorial directory. (then install lib2).
--
--          * When lib2 is already installed you can run edu.ex to start using
--            Euphoria 3.1.1 with lib2 syntax coloring support and help files.
--            Tip: you can also use the -u switch to run edu.ex in UTF-8 mode,
--                 for example in Linux run:
--                  exu edu -u filename.e
--
-- Details: you can merge lib2 with your current Euphoria 3.1.1 installation by
--          yourself, or you can run install.ex to do it automatically.
--
--          how to use install.ex:
--
--          - unzip lib2.zip (you already did).
--          - open your terminal.
--          - change the current drive and directory to install.ex's directory.
--          - make sure that Euphoria 3.1.1 is already installed correctly.
--          - make sure that EUDIR environment variable is already set.
--          - run install.ex to merge lib2 with your current Euphoria 3.1.1
--            installation, for example, in Linux run:
--              exu install.ex


include file.e
include get.e

-- clear keyboard
procedure clear_keys()
    while get_key() != -1 do
    end while
end procedure

-- pause
procedure wait()
    while get_key() = -1 do
    end while
end procedure

-- print error message and abort
procedure error(sequence msg)
    puts(1, "\n\n" & msg)
    clear_keys()
    wait()
    puts(1, '\n')
    abort(1)
end procedure

-- prompt user to enter y or n key, returns 1 if yes, or 0 if no
function prompt_yn(sequence msg)
    sequence s
    integer yes

    s = prompt_string(msg & " [y,n]? ")

    -- verify string
    yes = 0
    for i = 1 to length(s) do
	if yes = 0 and (s[i] = 'y' or s[i] = 'Y') then
	    yes = 1
	elsif s[i] > 32 then -- (ignore control characters and space)
	    return 0
	end if
    end for
    return yes
end function


clear_screen()


-- verify environment
object eudir
eudir = getenv("EUDIR")
if atom(eudir) then
    error("EUDIR environment variable is not set.")
elsif atom(dir(eudir)) then
    error("EUDIR environment variable is wrong (" & eudir & ").")
elsif atom(dir("install.ex")) then
    error("install.ex must be in the current directory.")
end if


-- prompt user to start install
integer yn
yn = prompt_yn("\nMerge '" & current_dir() & "' with '" & eudir & "'")
if yn then
    yn = prompt_yn("Are you sure")
end if
if yn then
    puts(1, "\nStart installing... (Press Ctrl-C to stop)\n\n")
else
    error("install.ex canceled by user.")
end if


-- install ./euphoria directory tree using external system command
-- (you will be asked before overwriting existing files)
integer code
if platform() = DOS32 then -- (FreeDOS)
    code = system_exec("XCOPY " & ".\\euphoria\\*.* " & eudir & " /S /-Y", 2)

elsif platform() = WIN32 then -- (Windows-7)
    code = system_exec("XCOPY " & ".\\euphoria\\*.* " & eudir & " /s /-y", 2)

elsif platform() = LINUX then -- or FREEBSD (FreeBSD not tested)
    puts(1, "* Enter [y|n] to [overwrite|skip] existing file.\n\n") -- cp help

    code = system_exec("cp -riv " & "./euphoria/* " & eudir, 2)
end if

if code = 0 then -- 0 is normally "success"
    puts(1, "\nDone.\n")
    wait()
else
    error("An error occurred while installing.")
end if
